@@ -26,7 +26,7 @@ class _FlexiblePreview(UserMixin):
     }
     query = self.signed_query(params)
     r = await self.client.get(
-      f'{self.base}/sapi/v1/simple-earn/flexible/subscriptionPreview?{query}',
+      f'/sapi/v1/simple-earn/flexible/subscriptionPreview?{query}',
       headers={'X-MBX-APIKEY': self.api_key},
     )
     return validate_response(r.text, FlexiblePreviewResponse)
