@@ -7,7 +7,7 @@ class _Ping(ClientMixin):
   @ClientMixin.with_client
   async def ping(self):
     """https://developers.binance.com/docs/binance-spot-api-docs/rest-api/general-endpoints#test-connectivity"""
-    r = await self.client.get(f'{self.base}/api/v3/ping')
+    r = await self.client.get(f'/api/v3/ping')
     validate_response(r.text)
     
 
